@@ -5,7 +5,7 @@
 
 import sys
 
-if __package__ is None and not hasattr(sys, 'frozen'):
+if __package__ is None and not getattr(sys, 'frozen', False):
     # direct call of __main__.py
     import os.path
     path = os.path.realpath(os.path.abspath(__file__))
