@@ -1,6 +1,3 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 import re
 
 from .common import InfoExtractor
@@ -54,7 +51,7 @@ class NovaEmbedIE(InfoExtractor):
 
         player = self._parse_json(
             self._search_regex(
-                (r'(?:replacePlaceholders.*?:\s*)?replacePlaceholders\s*\(\s*(?P<json>{.*})\s*\)(?:\s*\))?\s*,',
+                (r'(?:(?:replacePlaceholders|processAdTagModifier).*?:\s*)?(?:replacePlaceholders|processAdTagModifier)\s*\(\s*(?P<json>{.*?})\s*\)(?:\s*\))?\s*,',
                     r'Player\.init\s*\([^,]+,(?P<cndn>\s*\w+\s*\?)?\s*(?P<json>{(?(cndn).+?|.+)})\s*(?(cndn):|,\s*{.+?}\s*\)\s*;)'),
                 webpage, 'player', default='{}', group='json'), video_id, fatal=False)
         if player:
@@ -126,7 +123,6 @@ class NovaEmbedIE(InfoExtractor):
 
         if not formats and has_drm:
             self.report_drm(video_id)
-        self._sort_formats(formats)
 
         title = self._og_search_title(
             webpage, default=None) or self._search_regex(
@@ -311,7 +307,6 @@ class NovaIE(InfoExtractor):
             formats = [{
                 'url': video_url,
             }]
-        self._sort_formats(formats)
 
         title = mediafile.get('meta', {}).get('title') or self._og_search_title(webpage)
         thumbnail = config.get('poster')
