@@ -149,8 +149,6 @@ class XVideosIE(InfoExtractor):
                     'quality': -2 if format_id.endswith('low') else None,
                 })
 
-        self._sort_formats(formats)
-
         return {
             'id': video_id,
             'formats': formats,
@@ -159,3 +157,24 @@ class XVideosIE(InfoExtractor):
             'thumbnails': thumbnails,
             'age_limit': 18,
         }
+
+
+class XVideosQuickiesIE(InfoExtractor):
+    IE_NAME = 'xvideos:quickies'
+    _VALID_URL = r'https?://(?P<domain>(?:[^/]+\.)?xvideos2?\.com)/amateur-channels/[^#]+#quickies/a/(?P<id>\d+)'
+    _TESTS = [{
+        'url': 'https://www.xvideos.com/amateur-channels/wifeluna#quickies/a/47258683',
+        'md5': '16e322a93282667f1963915568f782c1',
+        'info_dict': {
+            'id': '47258683',
+            'ext': 'mp4',
+            'title': 'Verification video',
+            'age_limit': 18,
+            'duration': 16,
+            'thumbnail': r're:^https://cdn.*-pic.xvideos-cdn.com/.+\.jpg',
+        }
+    }]
+
+    def _real_extract(self, url):
+        domain, id_ = self._match_valid_url(url).group('domain', 'id')
+        return self.url_result(f'https://{domain}/video{id_}/_', XVideosIE, id_)
